==> graphql-dgs-mocking-8.4.0-sources.jar: main/com/netflix/graphql/mocking/DgsSchemaTransformer.kt <==
/*
 * Copyright 2021 Netflix, Inc.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package com.netflix.graphql.mocking

import graphql.schema.*

class DgsSchemaTransformer {

    fun transformSchemaWithMockProviders(schema: GraphQLSchema, mockProviders: Set<MockProvider>): GraphQLSchema {
        val mockConfig = mutableMapOf<String, Any>()
        mockProviders.forEach { p -> mockConfig.putAll(p.provide()) }
        return transformSchema(schema, mockConfig)
    }

    fun transformSchema(schema: GraphQLSchema, mockConfig: Map<String, *>): GraphQLSchema {
        val mockFetchers = mutableMapOf<FieldCoordinates, DataFetcher<*>>()
        val graphQLTypeVisitorStub = MockGraphQLVisitor(mockConfig, mockFetchers)

        SchemaTraverser().depthFirstFullSchema(graphQLTypeVisitorStub, schema)

        return schema.transform { schemaBuilder ->
            val newCodeRegistry = schema.codeRegistry.transform { codeRegistryBuilder ->
                mockFetchers.forEach { (coordinates, dataFetcher) -> codeRegistryBuilder.dataFetcher(coordinates, dataFetcher) }
            }
            schemaBuilder.codeRegistry(newCodeRegistry)
        }
    }
}

==> graphql-dgs-mocking-9.1.0-sources.jar: main/com/netflix/graphql/mocking/DgsSchemaTransformer.kt <==
/*
 * Copyright 2021 Netflix, Inc.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package com.netflix.graphql.mocking

import graphql.schema.*

class DgsSchemaTransformer {
    fun transformSchemaWithMockProviders(
        schema: GraphQLSchema,
        mockProviders: Set<MockProvider>,
    ): GraphQLSchema {
        val mockConfig = mutableMapOf<String, Any>()
        mockProviders.forEach { p -> mockConfig.putAll(p.provide()) }
        return transformSchema(schema, mockConfig)
    }

    fun transformSchema(
        schema: GraphQLSchema,
        mockConfig: Map<String, *>,
    ): GraphQLSchema {
        val mockFetchers = mutableMapOf<FieldCoordinates, DataFetcher<*>>()
        val graphQLTypeVisitorStub = MockGraphQLVisitor(mockConfig, mockFetchers)

        SchemaTraverser().depthFirstFullSchema(graphQLTypeVisitorStub, schema)

        return schema.transform { schemaBuilder ->
            val newCodeRegistry =
                schema.codeRegistry.transform { codeRegistryBuilder ->
                    mockFetchers.forEach { (coordinates, dataFetcher) -> codeRegistryBuilder.dataFetcher(coordinates, dataFetcher) }
                }
            schemaBuilder.codeRegistry(newCodeRegistry)
        }
    }
}
